% t_readme.m
% 3/Aug/01
%
%
%                    Tidal Analysis Toolbox
%
% The tidal analysis toolbox uses harmonic analysis to estimate tidal
% consitutents and their uncertainities in scalar and vector time series. 
%
% This package is based on a FORTRAN package developed by M. G.
% G. Foreman and coworkers at the Institute of Ocean Sciences (IOS). (The
% IOS tidal package and user manuals are available from Foreman at
% http://www.ios.bc.ca/ios/iap/pages/tidpack.htm.). S. Lentz and 
% B. Beardsley (WHOI) began translating the code into matlab, 
% and improved the error estimation using matlab spectrum code. 
% R. Pawlowicz (UBC) then completely rewrote it using complex (rather 
% than real) math, adding inference, a user interface, and lots of other 
% goodies, including an error analysis. If you want to make use of the
% error analysis it is strongly recommended that you read T_ERRORS.
%
% Caveats: - Presently the nodal corrections are done in such a way that they
% may not be too accurate for time series longer than a year or so (corrections
% are based on the middle time of the input series). The hand-me-down advice for
% this case is "break up your series into yearly chunks and do successive analyses",
% unless you have 19 years or more in which case nodal corrections aren't
% necesary. In THAT case feel free to recode so that all constituents are
% analyzed without the need for nodal corrections.
%
% Tidal predictions are also based on nodal corrections at the center time.
%
% Shallow water constituents are not used automatically. They can
% be used but you must specify them manually using 'shallow' input option
% to T_TIDE (you can get the names and frequencies of shallow water
% constituents from the CONST structure returned by T_GETCONSTS).
% 
% Note that T_TIDE has options for pretty much anything you could possibly
% want to do -  type 'help t_tide' for more info.
%
%------------------------------------------------------------------------------
%
% PSD and CSD: Currently the functions psd.m and csd.m from the SIGNAL PROCESSING
% toolbox are called when the default confidence interval calculation is used.
% If you don't have these functions, you can still do things by specifying 
% another algorithms, e.g.
%
%  [...]=t_tide(...'error','wboot')
%
%-----------------------------------------------------------------------------
%
% The toolbox presently contains the following mfiles:
%
% ---FOR ANALYSIS
% t_tide.m       - computes the tidal analysis of the real or complex 
%                  time series.
%
% t_predic.m     - computes a tidal prediction using the results of t_tide.
%
% t_vuf.m        - computes nodal corrections and astronomical arguments.
%
% t_getconst.m   - loads constituent data of all kinds (based on the data file
%                  from the fortran package)
%
% ---FOR DOCUMENTATION
%
% t_readme.m     - this file.
%
% t_error.m      - a long discussion of confidence intervals and how they
%                  can be generated.
%
% ---FOR DEMONSTRATION
%
% t_synth.m     - synthesizes noisy data to test real as opposed to
%                 estimated uncertainties (crufty code).
%
% t_demo.m    - a short example using the Tuktoyuktok elevation data.
%
% ---FOR FUN
%
% t_equilib.m    - computes the equilibrium amplitudes of main constituents
%                  at a given latitude.
%
%
% Various data files are also included:
%
% tide3.dat      - standard constituent data file from the IOS analysis package.
%                  (read once and then results stored in various data structures
%                   in t_constituents.mat)
% t_equilib.dat  - Equilibrium amplitude A and B factors (read once and then 
%                  stored in t_constituents.mat)
%
% t_constituents.mat - constituent data structures
%
% t_example.mat - Sample Tuktoyuktuk elevation data set used as an example in
%                  PMSR-77/10 (IOS tide package check-example).
% 
%
%
%  CHANGES
%
%  0.98 - fix: t_tide and t_predic did not mirror image in cases where either
%         start time or latitude were not specified in earlier versions. 
%
% Questions or comments to:
% R. Pawlowicz (rich@ocgy.ubc.ca) 14/Feb/01

